import { useState } from "react";
import { Box, Typography } from "@mui/material";
import { styled, useTheme } from "@mui/material/styles";
import SettingsIcon from '@mui/icons-material/Settings';

import Modal from "../../../components/Modal/Modal";
import { PrimaryButton } from "../../../components/Button";

import { DecimalBigNumber } from "../../../helpers/DecimalBigNumber";
import { formatNumber } from "../../../helpers";

import { purchaseBond } from "../../../hooks/bonds";
import { claim } from "../../../hooks/staking";

const StyledBox = styled(Box, {
    shouldForwardProp: prop => prop !== "template",
})(({ theme }) => {
    return {
        root: {},
    };
});

const WarmupConfirmModal = ({
    chainId,
    address,
    warmupLength,
    isOpen,
    handleConfirmClose,
    setPreClaimConfirmed
}) => {
    const theme = useTheme();

    const onSubmit = () => {
        setPreClaimConfirmed();
        handleConfirmClose();
    }

    return (
        <Modal
            maxWidth="476px"
            minHeight={warmupLength >= 0 ? "150px" : "200px"}
            open={isOpen}
            headerText={
                warmupLength >= 0
                    ? "Bond Warm-Up is Pending..."
                    : "Unlock Bond"
            }
            onClose={handleConfirmClose}
        >
            <Box gap="20px" display="flex" flexDirection="column" justifyContent="space-between" alignItems="center">
                <Box display="flex" flexDirection="column">
                    <Typography>{
                        warmupLength >= 0
                            ? `This bond is currently in a warm-up period and cannot be claimed yet. It'll be available for claim in ${warmupLength} epochs.`
                            : "This bond is warmed-up and can be unlocked. Please unlock it on behalf of the collective."
                    }</Typography>
                </Box>

                {warmupLength < 0 && <PrimaryButton fullWidth onClick={onSubmit}>
                    Confirm
                </PrimaryButton>}
            </Box>
        </Modal>
    );
};

export default WarmupConfirmModal;
